"""
Exports function list_versions() for unicode version level support.

This code generated by {{this_filepath}} on {{utc_now}}.
"""


def list_versions():
    """
    Return Unicode version levels supported by this module release.

    Any of the version strings returned may be used as keyword argument
    ``unicode_version`` to the ``wcwidth()`` family of functions.

    :returns: Supported Unicode version numbers in ascending sorted order.
    :rtype: list[str]
    """
    return (
{%- for version in versions %}
        "{{version}}",
{%- endfor %}
    )
